@@ -1,6 +1,6 @@
 package Map::Tube::CLI::Option;
 
-$Map::Tube::CLI::Option::VERSION   = '0.69';
+$Map::Tube::CLI::Option::VERSION   = '0.70';
 $Map::Tube::CLI::Option::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::CLI::Option - Option as Moo Role for Map::Tube::CLI.
 
 =head1 VERSION
 
-Version 0.69
+Version 0.70
 
 =cut
 
@@ -23,15 +23,16 @@ use Types::Standard -all;
 use MooX::Options;
 
 has maps             => (is => 'rw');
-option map           => (is => 'ro', order => 1, isa => Str, format => 's', required => 1, doc => 'Map name');
-option start         => (is => 'ro', order => 2, isa => Str, format => 's', doc => 'Start station name');
-option end           => (is => 'ro', order => 3, isa => Str, format => 's', doc => 'End station name'  );
-option preferred     => (is => 'ro', order => 4, doc => 'Show preferred route');
-option generate_map  => (is => 'ro', order => 5, doc => 'Generate map as image');
-option line          => (is => 'ro', order => 6, isa => Str, format => 's', doc => 'Line name for map'    );
-option bgcolor       => (is => 'ro', order => 7, isa => Str, format => 's', doc => 'Map background color' );
-option line_mappings => (is => 'ro', order => 8, doc => 'Generate line mappings');
-option line_notes    => (is => 'ro', order => 9, doc => 'Generate line notes');
+option map           => (is => 'ro', order => 1,  isa => Str, format => 's', required => 1, doc => 'Map name');
+option start         => (is => 'ro', order => 2,  isa => Str, format => 's', doc => 'Start station name');
+option end           => (is => 'ro', order => 3,  isa => Str, format => 's', doc => 'End station name'  );
+option preferred     => (is => 'ro', order => 4,  doc => 'Show preferred route');
+option generate_map  => (is => 'ro', order => 5,  doc => 'Generate map as image');
+option line          => (is => 'ro', order => 6,  isa => Str, format => 's', doc => 'Line name for map'    );
+option bgcolor       => (is => 'ro', order => 7,  isa => Str, format => 's', doc => 'Map background color' );
+option line_mappings => (is => 'ro', order => 8,  doc => 'Generate line mappings');
+option line_notes    => (is => 'ro', order => 9,  doc => 'Generate line notes');
+option list_lines    => (is => 'ro', order => 10, doc => 'List lines');
 
 =head1 DESCRIPTION
 
@@ -61,10 +62,14 @@ You can also look for information at:
 
 =over 4
 
-=item * BUGS / ISSUES
+=item * BUG Report
 
 L<https://github.com/manwar/Map-Tube-CLI/issues>
 
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Map-Tube-CLI>
+
 =item * Search MetaCPAN
 
 L<http://metacpan.org/dist/Map-Tube-CLI/>
